summaryrefslogtreecommitdiff
path: root/include/X11/Xaw/Toggle.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/X11/Xaw/Toggle.h')
-rw-r--r--include/X11/Xaw/Toggle.h123
1 files changed, 64 insertions, 59 deletions
diff --git a/include/X11/Xaw/Toggle.h b/include/X11/Xaw/Toggle.h
index a433bd0..68bb742 100644
--- a/include/X11/Xaw/Toggle.h
+++ b/include/X11/Xaw/Toggle.h
@@ -23,6 +23,7 @@ Except as contained in this notice, the name of The Open Group shall not be
used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from The Open Group.
*/
+/* $XFree86: xc/lib/Xaw/Toggle.h,v 1.6 2001/12/14 19:54:45 dawes Exp $ */
/*
* ToggleP.h - Private definitions for Toggle widget
@@ -37,12 +38,6 @@ in this Software without prior written authorization from The Open Group.
#ifndef _XawToggle_h
#define _XawToggle_h
-/***********************************************************************
- *
- * Toggle Widget
- *
- ***********************************************************************/
-
#include <X11/Xaw/Command.h>
/* Resources:
@@ -60,6 +55,7 @@ in this Software without prior written authorization from The Open Group.
callback Callback Pointer NULL
cursor Cursor Cursor None
destroyCallback Callback Pointer NULL
+ displayList DisplayList XawDisplayList* NULL
font Font XFontStructx* XtDefaultFont
foreground Foreground Pixel XtDefaultForeground
height Height Dimension text height
@@ -86,10 +82,8 @@ in this Software without prior written authorization from The Open Group.
/*
* These should be in StringDefs.h but aren't so we will define
- * them here if they are needed.
+ * them here if they are needed
*/
-
-
#define XtCWidget "Widget"
#define XtCState "State"
#define XtCRadioGroup "RadioGroup"
@@ -108,68 +102,79 @@ extern WidgetClass toggleWidgetClass;
typedef struct _ToggleClassRec *ToggleWidgetClass;
typedef struct _ToggleRec *ToggleWidget;
-
-/************************************************************
- *
+/*
* Public Functions
- *
- ************************************************************/
+ */
_XFUNCPROTOBEGIN
-/* Function Name: XawToggleChangeRadioGroup
- * Description: Allows a toggle widget to change radio lists.
- * Arguments: w - The toggle widget to change lists.
- * radio_group - any widget in the new list.
- * Returns: none.
+/*
+ * Function:
+ * XawToggleChangeRadioGroup
+ *
+ * Parameters:
+ * w - toggle widget to change lists
+ * radio_group - any widget in the new list
+ *
+ * Description:
+ * Allows a toggle widget to change radio lists.
*/
+void XawToggleChangeRadioGroup
+(
+ Widget w,
+ Widget radio_group
+ );
-extern void XawToggleChangeRadioGroup(
-#if NeedFunctionPrototypes
- Widget /* w */,
- Widget /* radio_group */
-#endif
-);
-
-/* Function Name: XawToggleGetCurrent
- * Description: Returns the RadioData associated with the toggle
+/*
+ * Function:
+ * XawToggleGetCurrent
+ *
+ * Parameters:
+ * radio_group - any toggle widget in the toggle list
+ *
+ * Description:
+ * Returns the RadioData associated with the toggle
* widget that is currently active in a toggle list.
- * Arguments: radio_group - any toggle widget in the toggle list.
- * Returns: The XtNradioData associated with the toggle widget.
+ * Returns:
+ * The XtNradioData associated with the toggle widget
*/
-extern XtPointer XawToggleGetCurrent(
-#if NeedFunctionPrototypes
- Widget /* radio_group */
-#endif
-);
-
-/* Function Name: XawToggleSetCurrent
- * Description: Sets the Toggle widget associated with the
- * radio_data specified.
- * Arguments: radio_group - any toggle widget in the toggle list.
- * radio_data - radio data of the toggle widget to set.
- * Returns: none.
- */
+XtPointer XawToggleGetCurrent
+(
+ Widget radio_group
+ );
-extern void XawToggleSetCurrent(
-#if NeedFunctionPrototypes
- Widget /* radio_group */,
- XtPointer /* radio_data */
-#endif
-);
-
-/* Function Name: XawToggleUnsetCurrent
- * Description: Unsets all Toggles in the radio_group specified.
- * Arguments: radio_group - any toggle widget in the toggle list.
- * Returns: none.
+/*
+ * Function:
+ * XawToggleSetCurrent
+ *
+ * Parameters:
+ * radio_group - any toggle widget in the toggle list
+ * radio_data - radio data of the toggle widget to set
+ *
+ * Description:
+ * Sets the Toggle widget associated with the radio_data specified.
*/
+void XawToggleSetCurrent
+(
+ Widget radio_group,
+ XtPointer radio_data
+ );
-extern void XawToggleUnsetCurrent(
-#if NeedFunctionPrototypes
- Widget /* radio_group */
-#endif
-);
+/*
+ * Function:
+ * XawToggleUnsetCurrent
+ *
+ * Parameters:
+ * radio_group - any toggle widget in the toggle list
+ *
+ * Description:
+ * Unsets all Toggles in the radio_group specified.
+ */
+void XawToggleUnsetCurrent
+(
+ Widget radio_group
+ );
_XFUNCPROTOEND